### CHANGE LOG
---

#### 1.0.1 (29/01/2024)
- First Release

#### 1.0.2 (02/02/2024)
- First Revision, Including:
    - Axes in the plot is now available
    - Windrose plot is now available (not include subplots)
    - demo4, demo9 released
    - README.md updated

#### 1.0.3 (08/02/2024)
- Fixing the bug in the installation process
- README.md updated

#### 1.0.4 (15/02/2024)
- Fixing the bug in the installation process
- New feature: bp.record() is now available

#### 1.0.5 (01/03/2024)
- Fixing the bug in the importing process
- New feature: bp.add_watermark() is now available

#### 1.0.6 (19/04/2024)
- Fixing the bug of using zh font in the plot
- Some cmaps are available

#### 1.0.7 (19/05/2024)
- Add some new cmaps

#### 1.0.8 (23/05/2024)
- Add the new cmaps
- New feature: bp.convertgif() is now available

#### 1.0.9 (23/05/2024)
- Fix some minor bugs

#### 1.0.10 (07/07/2024)
- Add the new cmaps
- Add new features about 3D plots
- Add new demo about 3D plots

#### 1.0.11 (08/07/2024)
- Add the new cmap
- Add new feature: bp.voxels() is now available

#### 1.0.12 (11/07/2024)
- Add the new cmaps, `309` is for blindness-friendly

#### 1.0.13 (24/07/2024)
- Add the new cmaps `319`
- Minor issues fixed about the ticks and labels

#### 1.0.14 (02/10/2024)
- Add the new cmaps `329`

#### 1.0.15 (12/03/2025)
- Add new fonttype `zhbold` and `kl`, make sure the font files are downloaded before using them
- Add the `contourf(returnCTF)`, `rcontourf(returnCTF)`, `contourf3d(returnCTF)`, and `colorbar(inputCTF)` arguments to operate the CTF variables directly.
- Fix the bugs in contourf.

#### 1.0.16 (05/07/2025)
- Add new function `bp.tricontourf()`, which is used to plot tricontourf plots.
- Add new function `bp.tricontour()`, which is used to plot tricontours.

#### 1.0.17 (20/07/2025)
- Add new function `bp.pilltitle()`
- Arguments rename: now using `facecolor` and `edgecolor` in `boxplot()`, `annotate_wedge()`, `textbox()`, and `pilltitle()`.

#### 1.1.0 (11/09/2025)
- Rewrite config system.
- Rewrite `bp.initplot()`, use `bp.initfig()` and `bp.initax()` now.
- Fix mappable functions and `bp.colorbar()` logic.
- Add a lot of new functions such as `bp.hexbin()`.

#### 1.1.4 (12/09/2025)
- Fix some bugs.
- Add new cmaps `339`.

#### 1.1.6 (03/10/2025)
- Fix some bugs about `bp.initfig()` and `bp.legend()`.
- Add new cmaps `349`.